@@ -20,7 +20,13 @@ dbRunScript = function(db, fn)
 }
 
 
-dbExists = function(db, query, data) (nrow(dbGetQuery_param(db, query, data)) > 0)
+dbExists = function(db, query, data=NULL){
+  if(is.null(data))
+    nrow(dbGetQuery(db, query)) > 0
+  else
+    nrow(dbGetQuery_param(db, query, data)) > 0
+  
+} 
 
 dbCheck_reserved_colnames = function(nm)
 {
